@@ -6,14 +6,20 @@ DeliveryForm = function (params) {
         $warehouse = params.$warehouse,
         deliveryMethods = params.deliveryMethods,
         citiesUrl = params.citiesUrl,
-        warehousesUrl = params.warehousesUrl;
+        warehousesUrl = params.warehousesUrl,
+        $warehouseLabel = $('[data-role=warehouse-label]'),
+        $addressLabel = $('[data-role=address-label]'),
+        $deliveryTypes = $('[data-role=novaposhta-delivery-types]'),
+        $selfDeliveryOption = $('[data-role=novaposhtaselfdelivery]');
 
     setEvents();
     handleDeliveryMethodChange();
+    updateAddressLabel();
 
     function setEvents() {
         $deliveryMethod.on('change', handleDeliveryMethodChange);
         $city.on('change', handleCityChange);
+        $('[name=novaposhtatype]').change(updateAddressLabel);
     }
 
     function handleDeliveryMethodChange() {
@@ -25,6 +31,7 @@ DeliveryForm = function (params) {
 
         $city.parent()[action]();
         $warehouse.parent()[action]();
+        $deliveryTypes[action]();
 
         $city.autocomplete({
             serviceUrl: citiesUrl,
@@ -49,6 +56,16 @@ DeliveryForm = function (params) {
         $warehouse.autocomplete('setOptions', {params: getWarehouseParams()});
     }
 
+    function updateAddressLabel() {
+        if ($selfDeliveryOption.is(':checked')) {
+            $warehouseLabel.show();
+            $addressLabel.hide();
+        } else {
+            $warehouseLabel.hide();
+            $addressLabel.show();
+        }
+    }
+
     function getWarehouseParams() {
         return {
             delivery_method: $deliveryMethod.val(),
